@@ -1,5 +1,6 @@
 var NAVTREEINDEX79 =
 {
+"vector__sink__f__pydoc__template_8h.html#ac27d1f4dc1e53b72a8d65e8a0905f043":[7,0,29,2,0,0,0,27,38],
 "vector__sink__f__pydoc__template_8h.html#ac6379a9527bca6ee9af332b95ba9b342":[7,0,29,2,0,0,0,27,15],
 "vector__sink__f__pydoc__template_8h.html#aceb810b0fb1b9ec770224c3f7c941ff7":[7,0,29,2,0,0,0,27,31],
 "vector__sink__f__pydoc__template_8h.html#ad705e17d7c739c48e89419509485421b":[7,0,29,2,0,0,0,27,35],
@@ -40,8 +41,16 @@ var NAVTREEINDEX79 =
 "vectordisplayform__pydoc__template_8h.html":[7,0,29,2,0,0,0,28],
 "vectordisplayform__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,29,2,0,0,0,28,0],
 "vectordisplayform__pydoc__template_8h_source.html":[7,0,29,2,0,0,0,28],
-"viterbi__combined_8h.html":[7,0,32,0,0,0,21],
-"viterbi__combined_8h_source.html":[7,0,32,0,0,0,21],
+"version_8h.html":[7,0,2,0,0,1],
+"version_8h.html#a132bd21ddc5ccf3142c6d69d85c889b6":[7,0,2,0,0,1,4],
+"version_8h.html#a6bb869d80dc73dd6348f80f3702c72a2":[7,0,2,0,0,1,0],
+"version_8h.html#a7528a9e21cf1443f7ed8f7cfc8f3b09d":[7,0,2,0,0,1,3],
+"version_8h.html#aa1f39dad92207664c29ee85cb8c52fbf":[7,0,2,0,0,1,5],
+"version_8h.html#ac83383f3151b304dbfe803d479d598d7":[7,0,2,0,0,1,1],
+"version_8h.html#ae7e2b5260570107a48cda3b2daa97e03":[7,0,2,0,0,1,2],
+"version_8h_source.html":[7,0,2,0,0,1],
+"viterbi__combined_8h.html":[7,0,32,0,0,0,20],
+"viterbi__combined_8h_source.html":[7,0,32,0,0,0,20],
 "viterbi__combined__pydoc__template_8h.html":[7,0,32,1,0,0,0,19],
 "viterbi__combined__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[7,0,32,1,0,0,0,19,0],
 "viterbi__combined__pydoc__template_8h_source.html":[7,0,32,1,0,0,0,19],
